// Copyright 1998-2016 Epic Games, Inc. All Rights Reserved.

#include "ViveportLicenseCheckerPrivatePCH.h"


#include "Core.h"
#include "ModuleManager.h"
//#include "IPluginManager.h"

#include "AndroidApplication.h"

#define LOCTEXT_NAMESPACE "FViveportLicenseCheckerModule"

void FViveportLicenseCheckerModule::StartupModule()
{
	// This code will execute after your module is loaded into memory; the exact timing is specified in the .uplugin file per-module

	UE_LOG(LogTemp, Display, TEXT("StartupModule"));
}

void FViveportLicenseCheckerModule::ShutdownModule()
{
	// This function may be called during shutdown to clean up your module.  For modules that support dynamic reloading,
	// we call this function before unloading the module.

	UE_LOG(LogTemp, Display, TEXT("ShutdownModule"));

}

#undef LOCTEXT_NAMESPACE

IMPLEMENT_MODULE(FViveportLicenseCheckerModule, ViveportLicenseChecker)

ViveportLicenseChecker::ViveportLicenseChecker(const char *appId, const char *encodedPublicKey)
{
	UE_LOG(LogTemp, Display, TEXT("(%p) ViveportLicenseChecker::ViveportLicenseChecker"), this);

	mJEnv = FAndroidApplication::GetJavaEnv();
	UE_LOG(LogTemp, Display, TEXT("GetJavaEnv = %p"), mJEnv);

	//package com.htc.store.licensing;
	jclass jClass = FAndroidApplication::FindJavaClass("com/htc/store/licensing/LicenseCheckerPolling");
	UE_LOG(LogTemp, Display, TEXT("find LicenseCheckerPolling OK (%p)"), jClass);

	mCheckAccessMethod = mJEnv->GetMethodID(jClass, "checkAccess", "()V");
	mGetResultMethod = mJEnv->GetMethodID(jClass, "getResult", "()I");
	mOnDestroyMethod = mJEnv->GetMethodID(jClass, "onDestroy", "()V");
	mClearCacheMethod = mJEnv->GetMethodID(jClass, "clearCache", "()V");

	bool bSucc = mCheckAccessMethod && mGetResultMethod && mOnDestroyMethod && mClearCacheMethod;
	UE_LOG(LogTemp, Display, TEXT("GetMethodID = %p , %p , %p , %p"), mCheckAccessMethod, mGetResultMethod, mOnDestroyMethod, mClearCacheMethod);

	//public LicenseCheckerPolling(Context context, String appId, String encodedPublicKey)
	jmethodID helperConstructor = mJEnv->GetMethodID(jClass, "<init>", "(Landroid/content/Context;Ljava/lang/String;Ljava/lang/String;)V");
	jobject GameActivity = FAndroidApplication::GetGameActivityThis();
	jstring jAppId = mJEnv->NewStringUTF(appId);
	jstring jAppKey = mJEnv->NewStringUTF(encodedPublicKey);
	mJObject = mJEnv->NewObject(jClass, helperConstructor, GameActivity, jAppId, jAppKey);
	mJObject = mJEnv->NewGlobalRef(mJObject);
	UE_LOG(LogTemp, Display, TEXT("LicenseCheckerPolling java Obj =%p"), mJObject);
}

ViveportLicenseChecker::~ViveportLicenseChecker()
{	
	UE_LOG(LogTemp, Display, TEXT("(%p) ViveportLicenseChecker::~ViveportLicenseChecker()"), this);

	mJEnv->CallVoidMethod(mJObject, mOnDestroyMethod, nullptr);
	mJEnv->DeleteGlobalRef(mJObject);	
}

void ViveportLicenseChecker::CheckAccess()
{
	UE_LOG(LogTemp, Display, TEXT("(%p) ViveportLicenseChecker::CheckAccess()"), this);	
	mJEnv->CallVoidMethod(mJObject, mCheckAccessMethod, nullptr);	
}

ViveportLicenseChecker::Results ViveportLicenseChecker::GetResult()
{	
	int result = mJEnv->CallIntMethod(mJObject, mGetResultMethod, nullptr);	
	UE_LOG(LogTemp, Display, TEXT("(%p) ViveportLicenseChecker::GetResult() ret %d"), this, result);	
	return static_cast<ViveportLicenseChecker::Results>(result);
}

void ViveportLicenseChecker::ClearCache()
{
	UE_LOG(LogTemp, Display, TEXT("(%p) ViveportLicenseChecker::ClearCache()"), this);	
	mJEnv->CallVoidMethod(mJObject, mClearCacheMethod, nullptr);	
}


