// Copyright 1998-2016 Epic Games, Inc. All Rights Reserved.

#pragma once



#include "ModuleManager.h"
#include "AndroidJava.h"


class FViveportLicenseCheckerModule : public IModuleInterface
{
public:

	/** IModuleInterface implementation */
	virtual void StartupModule() override;
	virtual void ShutdownModule() override;
};



class ViveportLicenseChecker
{
public:

	enum Results
	{
		UNKNOWN = 0, // Initial state.
		CHECK_IN_PROGRESS = -888, // Checking in progress.
		ALLOW_LICENSED = -999, // User is licensed to use your application.


		DENY_NOT_LICENSED = -1, // User is not licensed to use your application.
		DENY_RETRY = -2, // Your application cannot get license response data from drm_service. It was probably due to network or server problem, so we should give the user a chance to retry.
		DENY_NOT_SIGN_IN = -3, // User did not add or sign in HTC Account.
		DENY_NO_SERVICE = -4, // Cannot bind DRM Service. Viveport client did not been installed.
		DENY_LICENSE_EXPIRED = -5, // The License is expired.
		DENY_EXCEED_MAX_DEVICES = -6, //

		ERROR_INVALID_PUBLIC_KEY = 5, // Invalid public key.
		ERROR_MISSING_PERMISSION = 6, // Missing permission. (reserved)
		ERROR_INVALID_APP_ID = 307, // Cannot find this App in Viveport .
	};

	ViveportLicenseChecker(const char* appId, const char* encodedPublicKey);
	virtual ~ViveportLicenseChecker();
	Results GetResult();	
	void CheckAccess();
	void ClearCache(); // for test

private:

	JNIEnv* mJEnv;
	jobject mJObject;
	jmethodID mCheckAccessMethod;
	jmethodID mGetResultMethod;
	jmethodID mOnDestroyMethod;
	jmethodID mClearCacheMethod;
};