package com.example.company.drmsample;

import android.os.Bundle;
import android.os.Handler;
import android.support.design.widget.FloatingActionButton;
import android.support.design.widget.Snackbar;
import android.support.v7.app.AppCompatActivity;
import android.support.v7.widget.Toolbar;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.TextView;

// {************ DRM ************(1)
//  Import drm modules
import com.htc.store.licensing.LicenseChecker;
import com.htc.store.licensing.LicenseCheckerCallback;
// }************ DRM ************(1)

public class MainActivity extends AppCompatActivity {

    // {************ DRM ************(2)
    // Implement LicenseCheckerCallback

    private class MyLicenseCheckerCallback implements LicenseCheckerCallback {
        public void allow() {
            if (isFinishing()) return; // Don't update UI if Activity is finishing.
            displayResult("allow"); // Should allow user access.
        }

        public void deny(int denyCode) {
            if (isFinishing()) return; // Don't update UI if Activity is finishing.
            switch (denyCode) {
                case DENY_NOT_LICENSED:
                    displayResult("not licensed");
                    break;

                case DENY_RETRY:
                    displayResult("please retry");
                    break;

                case DENY_NOT_SIGN_IN:
                    displayResult("please sign in");
                    break;

                case DENY_NO_SERVICE:
                    displayResult("please install Viveport client");
                    break;
            }

        }

        public void applicationError(int errorCode) {
            if (isFinishing()) return; // Don't update UI if Activity is finishing.

            // Please examine the error code and fix the error.
            displayResult("application_error: " + errorCode);
        }
    }
    // }************ DRM ************(2)

    private static final String TAG = "MainActivity";
    FloatingActionButton fab;
    // A handler on the UI thread.
    private Handler mHandler;
    private TextView mStatusText;

    // {************ DRM ************(3)
    //  Declare ViveportID, ViveportKey and Drm objects

    // Test Id and Test Key. All users will be allowed to use your app.
    private static final String sViveportID = "bd67b286-aafc-449d-8896-bb7e9b351876";
    private static final String sViveportKey = "MIGfMA0GCSqGSIb3DQEBAQUAA4GNADCBiQKBgQDFypCg0OHfBC+VZLSWPbNSgDo9qg/yQORDwGy1rKIboMj3IXn4Zy6h6bgn8kiMY7VI0lPwIj9lijT3ZxkzuTsI5GsK//Y1bqeTol4OUFR+47gj+TUuekAS2WMtglKox+/7mO6CA1gV+jZrAKo6YSVmPd+oFsgisRcqEgNh5MIURQIDAQAB";

    // use your Id & Key from developer console. It could be used to test DENY_NOT_LICENSED if the account on the testing device does not own the App.
    //private static final String sViveportID = "5cc23b56-0f0f-4e65-9b21-93c1be0ef8ed";
    //private static final String sViveportKey = "MIGfMA0GCSqGSIb3DQEBAQUAA4GNADCBiQKBgQCriAPI23fPc4Gyac7LJVlhh8whPZ48CDR9HUWSVYovstRJYKu5HIyRTxkOb/TzrBKWjYsbrwQwaGNjm80RyxkUr7bOP4okHv/hNUAxHlUpu6+XVYt4CWnrGBPDOducATHRMWUtqQUk6UoFwbA0yktvk8sHFGfIqwEEmgSmmnQ4KQIDAQAB";

    //private static final String sViveportID ="f6156ae3-dfae-4adb-bcaa-356a3eba04cc";
    //private static final String sViveportKey = "MIGfMA0GCSqGSIb3DQEBAQUAA4GNADCBiQKBgQC+VjnuDIAJoGu3dvOo9it+ph8zgIQSvRSJcVB29WbOkKKqKZk57bQWo4UjR+5YPbipSVC6EHRtHT9/y0KAg355/JvGNY8+rXXDHEuhON2frufQwnUT8KUjkmPd4LA1BTHnO6S+GOdN40AesTeBZgwacmXHzxTIbyCgNZuHsPkxZwIDAQAB";

    private LicenseCheckerCallback mLicenseCheckerCallback = new MyLicenseCheckerCallback();
    private LicenseChecker mChecker;
    // }************ DRM ************(3)



    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        Toolbar toolbar = (Toolbar) findViewById(R.id.toolbar);
        setSupportActionBar(toolbar);

        fab = (FloatingActionButton) findViewById(R.id.fab);
        fab.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                Snackbar.make(view, "Replace with your own action", Snackbar.LENGTH_LONG).setAction("Action", null).show();
                doCheck(); // check license
            }
        });

        mHandler = new Handler();
        mStatusText = (TextView) findViewById(R.id.log);


        // {************ DRM ************(4)
        mChecker = new LicenseChecker(this, sViveportID, sViveportKey); // Create LicenseChecker
        mChecker.clearCache(); // You could clear cache for testing purpose. Do not call it in normal case.
        // }************ DRM ************(4)
    }


    @Override
    protected void onDestroy() {
        super.onDestroy();
        // {************ DRM ************(5)
        mChecker.onDestroy();   // Destroy LicenseChecker
        // }************ DRM ************(5)
    }


    private void doCheck() {

        if (mChecker == null) {
            displayResult("mmChecker==null");
            return;
        }

        fab.setEnabled(false);
        setProgressBarIndeterminateVisibility(true);
        mStatusText.setText("checking_license");

        // {************ DRM ************(6)
        mChecker.checkAccess(mLicenseCheckerCallback); // Check License.
        // }************ DRM ************(6)
    }


    private void displayResult(final String result) {
        mHandler.post(new Runnable() {
            public void run() {
                mStatusText.setText(result);
                setProgressBarIndeterminateVisibility(false);
                fab.setEnabled(true);
            }
        });
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.menu_main, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        // Handle action bar item clicks here. The action bar will
        // automatically handle clicks on the Home/Up button, so long
        // as you specify a parent activity in AndroidManifest.xml.
        int id = item.getItemId();

        //noinspection SimplifiableIfStatement
        if (id == R.id.action_settings) {
            return true;
        }

        return super.onOptionsItemSelected(item);
    }


}
